summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--README4
-rw-r--r--configure.ac8
-rw-r--r--doc/lib/Makefile.am4
-rw-r--r--examples/Makefile.am4
-rw-r--r--examples/call-handler.c4
-rw-r--r--python/Makefile.am2
-rw-r--r--python/examples/callchannel.py50
-rw-r--r--telepathy-farstream/Makefile.am4
-rw-r--r--telepathy-farstream/call-channel.c10
-rw-r--r--telepathy-farstream/call-channel.h3
-rw-r--r--telepathy-farstream/call-content.c27
-rw-r--r--telepathy-farstream/call-stream.c14
-rw-r--r--telepathy-farstream/channel.c8
-rw-r--r--telepathy-farstream/content-priv.h2
-rw-r--r--telepathy-farstream/content.c12
-rw-r--r--telepathy-farstream/content.h2
-rw-r--r--telepathy-farstream/media-signalling-channel.c8
-rw-r--r--telepathy-farstream/media-signalling-content.c20
-rw-r--r--telepathy-farstream/session.c32
-rw-r--r--telepathy-farstream/stream.c94
-rw-r--r--telepathy-farstream/stream.h2
-rw-r--r--telepathy-farstream/telepathy-farstream-uninstalled.pc.in4
-rw-r--r--telepathy-farstream/telepathy-farstream.pc.in4
-rw-r--r--telepathy-farstream/utils.h4
24 files changed, 166 insertions, 160 deletions
diff --git a/README b/README
index 498fc7f..3a18752 100644
--- a/README
+++ b/README
@@ -2,7 +2,7 @@
telepathy-farstream
=======================
-Telepathy Farstream is a Telepathy client library that uses Farsight2
+Telepathy Farstream is a Telepathy client library that uses Farstream
to handle Call channels.
Telepathy is a D-Bus framework for unifying real time communication,
@@ -15,7 +15,7 @@ Requirements
telepathy-farstream requires:
telepathy-glib <http://telepathy.freedesktop.org/releases/telepathy-glib/>
- Farsight2 <http://farsight.freedesktop.org/releases/farsight/>
+ Farstream <http://farsight.freedesktop.org/releases/farstream/>
GStreamer base plugins <http://gstreamer.freedesktop.org/>
GLib, GObject <http://ftp.gnome.org/pub/GNOME/sources/glib/>
libdbus <http://dbus.freedesktop.org/releases/dbus/>
diff --git a/configure.ac b/configure.ac
index 21a12e0..67cf5b4 100644
--- a/configure.ac
+++ b/configure.ac
@@ -103,11 +103,11 @@ PKG_CHECK_MODULES([TELEPATHY], [telepathy-glib >= 0.13.4])
AC_SUBST(TELEPATHY_CFLAGS)
AC_SUBST(TELEPATHY_LIBS)
-dnl Check for farsight
-PKG_CHECK_MODULES(FARSIGHT2, [farsight2-0.10 >= 0.0.29])
+dnl Check for farstream
+PKG_CHECK_MODULES(FARSTREAM, [farstream-0.1 >= 0.1.0])
-AC_SUBST(FARSIGHT2_CFLAGS)
-AC_SUBST(FARSIGHT2_LIBS)
+AC_SUBST(FARSTREAM_CFLAGS)
+AC_SUBST(FARSTREAM_LIBS)
dnl Always required to generate extensions
AM_PATH_PYTHON([2.5])
diff --git a/doc/lib/Makefile.am b/doc/lib/Makefile.am
index 1c296e1..59bfce7 100644
--- a/doc/lib/Makefile.am
+++ b/doc/lib/Makefile.am
@@ -72,7 +72,7 @@ INCLUDES= \
$(X11_CFLAGS) \
$(GST_CFLAGS) \
$(GST_INTERFACES_CFLAGS) \
- $(FARSIGHT2_CFLAGS) \
+ $(FARSTREAM_CFLAGS) \
$(TELEPATHY_CFLAGS) \
-I$(top_srcdir) -I$(top_builddir)
GTKDOC_LIBS= \
@@ -82,7 +82,7 @@ GTKDOC_LIBS= \
$(GST_LIBS) \
$(GST_INTERFACES_LIBS) \
$(TELEPATHY_LIBS) \
- $(FARSIGHT2_LIBS) \
+ $(FARSTREAM_LIBS) \
$(top_builddir)/telepathy-farstream/libtelepathy-farstream.la
# This includes the standard gtk-doc make rules, copied by gtkdocize.
diff --git a/examples/Makefile.am b/examples/Makefile.am
index 57ebca6..ff2e7c3 100644
--- a/examples/Makefile.am
+++ b/examples/Makefile.am
@@ -6,7 +6,7 @@ LDADD = \
$(GLIB_LIBS) \
$(DBUS_LIBS) \
$(GST_LIBS) \
- $(FARSIGHT2_LIBS) \
+ $(FARSTREAM_LIBS) \
$(TELEPATHY_LIBS)
AM_CFLAGS = \
@@ -14,7 +14,7 @@ AM_CFLAGS = \
$(GLIB_CFLAGS) \
$(DBUS_CFLAGS) \
$(GST_CFLAGS) \
- $(FARSIGHT2_CFLAGS) \
+ $(FARSTREAM_CFLAGS) \
$(TELEPATHY_CFLAGS) \
-I$(top_srcdir) \
-I$(top_builddir)
diff --git a/examples/call-handler.c b/examples/call-handler.c
index bda2f46..5385a26 100644
--- a/examples/call-handler.c
+++ b/examples/call-handler.c
@@ -20,8 +20,8 @@
#include <gst/gst.h>
#include <telepathy-glib/telepathy-glib.h>
#include <extensions/extensions.h>
-#include <gst/farsight/fs-element-added-notifier.h>
-#include <gst/farsight/fs-utils.h>
+#include <farstream/fs-element-added-notifier.h>
+#include <farstream/fs-utils.h>
#include <telepathy-farstream/telepathy-farstream.h>
typedef struct {
diff --git a/python/Makefile.am b/python/Makefile.am
index 5d5bf20..d1f3686 100644
--- a/python/Makefile.am
+++ b/python/Makefile.am
@@ -12,7 +12,7 @@ AM_CPPFLAGS = \
$(TELEPATHY_CFLAGS) \
$(PYTHON_INCLUDES) \
$(PYTPFARSTREAM_CFLAGS) \
- $(FARSIGHT2_CFLAGS) \
+ $(FARSTREAM_CFLAGS) \
$(DBUS_CFLAGS)
BUILT_SOURCES = \
diff --git a/python/examples/callchannel.py b/python/examples/callchannel.py
index 99c7fb8..f37c724 100644
--- a/python/examples/callchannel.py
+++ b/python/examples/callchannel.py
@@ -28,7 +28,7 @@ pygst.require("0.10")
import gst
import tpfarstream
-import farsight
+import farstream
from util import *
import gc
@@ -59,7 +59,7 @@ class CallChannel:
self.pipeline = gst.Pipeline()
self.pipeline.get_bus().add_watch(self.async_handler)
- self.notifier = notifier = farsight.ElementAddedNotifier()
+ self.notifier = notifier = farstream.ElementAddedNotifier()
notifier.set_properties_from_file("element-properties")
notifier.add(self.pipeline)
@@ -111,9 +111,9 @@ class CallChannel:
def src_pad_added (self, content, handle, stream, pad, codec):
type = content.get_property ("media-type")
- if type == farsight.MEDIA_TYPE_AUDIO:
+ if type == farstream.MEDIA_TYPE_AUDIO:
sink = gst.parse_bin_from_description("audioconvert ! audioresample ! audioconvert ! autoaudiosink", True)
- elif type == farsight.MEDIA_TYPE_VIDEO:
+ elif type == farstream.MEDIA_TYPE_VIDEO:
sink = gst.parse_bin_from_description("ffmpegcolorspace ! videoscale ! autovideosink", True)
self.pipeline.add(sink)
@@ -121,32 +121,32 @@ class CallChannel:
sink.set_state(gst.STATE_PLAYING)
def get_codec_config (self, media_type):
- if media_type == farsight.MEDIA_TYPE_VIDEO:
- codecs = [ farsight.Codec(farsight.CODEC_ID_ANY, "H264",
- farsight.MEDIA_TYPE_VIDEO, 0) ]
+ if media_type == farstream.MEDIA_TYPE_VIDEO:
+ codecs = [ farstream.Codec(farstream.CODEC_ID_ANY, "H264",
+ farstream.MEDIA_TYPE_VIDEO, 0) ]
if self.conn.GetProtocol() == "sip" :
- codecs += [ farsight.Codec(farsight.CODEC_ID_DISABLE, "THEORA",
- farsight.MEDIA_TYPE_VIDEO, 0) ]
+ codecs += [ farstream.Codec(farstream.CODEC_ID_DISABLE, "THEORA",
+ farstream.MEDIA_TYPE_VIDEO, 0) ]
else:
- codecs += [ farsight.Codec(farsight.CODEC_ID_ANY, "THEORA",
- farsight.MEDIA_TYPE_VIDEO, 0) ]
+ codecs += [ farstream.Codec(farstream.CODEC_ID_ANY, "THEORA",
+ farstream.MEDIA_TYPE_VIDEO, 0) ]
codecs += [
- farsight.Codec(farsight.CODEC_ID_ANY, "H263",
- farsight.MEDIA_TYPE_VIDEO, 0),
- farsight.Codec(farsight.CODEC_ID_DISABLE, "DV",
- farsight.MEDIA_TYPE_VIDEO, 0),
- farsight.Codec(farsight.CODEC_ID_ANY, "JPEG",
- farsight.MEDIA_TYPE_VIDEO, 0),
- farsight.Codec(farsight.CODEC_ID_ANY, "MPV",
- farsight.MEDIA_TYPE_VIDEO, 0),
+ farstream.Codec(farstream.CODEC_ID_ANY, "H263",
+ farstream.MEDIA_TYPE_VIDEO, 0),
+ farstream.Codec(farstream.CODEC_ID_DISABLE, "DV",
+ farstream.MEDIA_TYPE_VIDEO, 0),
+ farstream.Codec(farstream.CODEC_ID_ANY, "JPEG",
+ farstream.MEDIA_TYPE_VIDEO, 0),
+ farstream.Codec(farstream.CODEC_ID_ANY, "MPV",
+ farstream.MEDIA_TYPE_VIDEO, 0),
]
else:
codecs = [
- farsight.Codec(farsight.CODEC_ID_ANY, "SPEEX",
- farsight.MEDIA_TYPE_AUDIO, 16000 ),
- farsight.Codec(farsight.CODEC_ID_ANY, "SPEEX",
- farsight.MEDIA_TYPE_AUDIO, 8000 )
+ farstream.Codec(farstream.CODEC_ID_ANY, "SPEEX",
+ farstream.MEDIA_TYPE_AUDIO, 16000 ),
+ farstream.Codec(farstream.CODEC_ID_ANY, "SPEEX",
+ farstream.MEDIA_TYPE_AUDIO, 8000 )
]
return codecs
@@ -163,10 +163,10 @@ class CallChannel:
content.connect ("src-pad-added", self.src_pad_added)
- if mtype == farsight.MEDIA_TYPE_AUDIO:
+ if mtype == farstream.MEDIA_TYPE_AUDIO:
src = gst.parse_bin_from_description("audiotestsrc is-live=1 ! " \
"queue", True)
- elif mtype == farsight.MEDIA_TYPE_VIDEO:
+ elif mtype == farstream.MEDIA_TYPE_VIDEO:
src = gst.parse_bin_from_description("videotestsrc is-live=1 ! " \
"capsfilter caps=video/x-raw-yuv,width=320,height=240", True)
diff --git a/telepathy-farstream/Makefile.am b/telepathy-farstream/Makefile.am
index 414fefd..04f3c68 100644
--- a/telepathy-farstream/Makefile.am
+++ b/telepathy-farstream/Makefile.am
@@ -50,7 +50,7 @@ AM_CFLAGS = \
$(GLIB_CFLAGS) \
$(DBUS_CFLAGS) \
$(GST_CFLAGS) \
- $(FARSIGHT2_CFLAGS) \
+ $(FARSTREAM_CFLAGS) \
$(TELEPATHY_CFLAGS) \
-I$(top_srcdir) \
-I$(top_builddir)
@@ -59,7 +59,7 @@ libtelepathy_farstream_la_LIBADD = \
$(GLIB_LIBS) \
$(DBUS_LIBS) \
$(GST_LIBS) \
- $(FARSIGHT2_LIBS) \
+ $(FARSTREAM_LIBS) \
$(TELEPATHY_LIBS) \
../extensions/libfuture-extensions.la
diff --git a/telepathy-farstream/call-channel.c b/telepathy-farstream/call-channel.c
index bd42fc8..57c650f 100644
--- a/telepathy-farstream/call-channel.c
+++ b/telepathy-farstream/call-channel.c
@@ -24,7 +24,7 @@
*
* This class handles the
* org.freedesktop.Telepathy.Channel.Interface.Call on a
- * channel using Farsight2.
+ * channel using Farstream.
*/
@@ -32,7 +32,7 @@
#include <telepathy-glib/util.h>
#include <telepathy-glib/interfaces.h>
-#include <gst/farsight/fs-conference-iface.h>
+#include <farstream/fs-conference.h>
#include "extensions/extensions.h"
@@ -108,8 +108,8 @@ tf_call_channel_class_init (TfCallChannelClass *klass)
g_object_class_install_property (object_class, PROP_FS_CONFERENCES,
g_param_spec_boxed ("fs-conferences",
- "Farsight2 FsConference object",
- "GPtrArray of Farsight2 FsConferences for this channel",
+ "Farstream FsConference object",
+ "GPtrArray of Farstream FsConferences for this channel",
G_TYPE_PTR_ARRAY,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
@@ -684,7 +684,7 @@ _tf_call_channel_get_participant (TfCallChannel *channel,
}
}
- p = fs_conference_new_participant (fsconference, NULL, error);
+ p = fs_conference_new_participant (fsconference, error);
if (!p)
return NULL;
diff --git a/telepathy-farstream/call-channel.h b/telepathy-farstream/call-channel.h
index 6cde870..3848818 100644
--- a/telepathy-farstream/call-channel.h
+++ b/telepathy-farstream/call-channel.h
@@ -23,8 +23,7 @@
#include <glib-object.h>
#include <gst/gst.h>
-#include <gst/farsight/fs-conference-iface.h>
-#include <gst/farsight/fs-participant.h>
+#include <farstream/fs-conference.h>
#include <telepathy-glib/channel.h>
G_BEGIN_DECLS
diff --git a/telepathy-farstream/call-content.c b/telepathy-farstream/call-content.c
index a6fc408..9a6f23a 100644
--- a/telepathy-farstream/call-content.c
+++ b/telepathy-farstream/call-content.c
@@ -24,7 +24,7 @@
*
* This class handles the
* org.freedesktop.Telepathy.Channel.Interface.Call on a
- * channel using Farsight2.
+ * channel using Farstream.
*/
@@ -32,9 +32,9 @@
#include <telepathy-glib/util.h>
#include <telepathy-glib/interfaces.h>
-#include <gst/farsight/fs-conference-iface.h>
-#include <gst/farsight/fs-utils.h>
-#include <gst/farsight/fs-element-added-notifier.h>
+#include <farstream/fs-conference.h>
+#include <farstream/fs-utils.h>
+#include <farstream/fs-element-added-notifier.h>
#include <stdarg.h>
#include <string.h>
@@ -1401,7 +1401,7 @@ tf_call_content_bus_message (TfCallContent *content,
s = gst_message_get_structure (message);
- if (gst_structure_has_name (s, "farsight-error"))
+ if (gst_structure_has_name (s, "farstream-error"))
{
GObject *object;
const GValue *value = NULL;
@@ -1433,7 +1433,7 @@ tf_call_content_bus_message (TfCallContent *content,
ret = TRUE;
}
}
- else if (gst_structure_has_name (s, "farsight-codecs-changed"))
+ else if (gst_structure_has_name (s, "farstream-codecs-changed"))
{
FsSession *fssession;
const GValue *value;
@@ -1523,15 +1523,22 @@ _tf_call_content_get_fsstream_by_handle (TfCallContent *content,
if (!p)
return NULL;
- s = fs_session_new_stream (content->fssession, p, FS_DIRECTION_RECV,
- transmitter, stream_transmitter_n_parameters,
- stream_transmitter_parameters, error);
+ s = fs_session_new_stream (content->fssession, p, FS_DIRECTION_RECV, error);
if (!s)
{
_tf_call_channel_put_participant (content->call_channel, p);
return NULL;
}
+ if (!fs_stream_set_transmitter (s, transmitter,
+ stream_transmitter_parameters, stream_transmitter_n_parameters,
+ error))
+ {
+ g_object_unref (s);
+ _tf_call_channel_put_participant (content->call_channel, p);
+ return NULL;
+ }
+
cfs = g_slice_new (struct CallFsStream);
cfs->use_count = 1;
cfs->contact_handle = contact_handle;
@@ -1664,7 +1671,7 @@ streams_src_pads_iter_item (GstIterator *it, gpointer item)
{
struct CallFsStream *cfs = item;
- gst_iterator_push (it, fs_stream_get_src_pads_iterator (cfs->fsstream));
+ gst_iterator_push (it, fs_stream_iterate_src_pads (cfs->fsstream));
return GST_ITERATOR_ITEM_SKIP;
}
diff --git a/telepathy-farstream/call-stream.c b/telepathy-farstream/call-stream.c
index 43d0c38..7658c9b 100644
--- a/telepathy-farstream/call-stream.c
+++ b/telepathy-farstream/call-stream.c
@@ -24,14 +24,14 @@
*
* This class handles the
* org.freedesktop.Telepathy.Channel.Interface.Stream on a
- * channel using Farsight2.
+ * channel using Farstream.
*/
#include "call-stream.h"
#include <telepathy-glib/util.h>
#include <telepathy-glib/interfaces.h>
-#include <gst/farsight/fs-conference-iface.h>
+#include <farstream/fs-conference.h>
#include <stdarg.h>
#include <string.h>
@@ -475,7 +475,7 @@ tf_call_stream_add_remote_candidates (TfCallStream *self,
if (self->fsstream)
{
- if (!fs_stream_set_remote_candidates (self->fsstream, fscandidates,
+ if (!fs_stream_add_remote_candidates (self->fsstream, fscandidates,
&error))
{
tf_content_error (TF_CONTENT (self->call_content),
@@ -1066,7 +1066,7 @@ tf_call_stream_bus_message (TfCallStream *stream, GstMessage *message)
s = gst_message_get_structure (message);
- if (gst_structure_has_name (s, "farsight-error"))
+ if (gst_structure_has_name (s, "farstream-error"))
{
GObject *object;
const gchar *msg;
@@ -1105,7 +1105,7 @@ tf_call_stream_bus_message (TfCallStream *stream, GstMessage *message)
if (g_value_get_object (val) != stream->fsstream)
return FALSE;
- if (gst_structure_has_name (s, "farsight-new-local-candidate"))
+ if (gst_structure_has_name (s, "farstream-new-local-candidate"))
{
FsCandidate *candidate;
@@ -1115,11 +1115,11 @@ tf_call_stream_bus_message (TfCallStream *stream, GstMessage *message)
cb_fs_new_local_candidate (stream, candidate);
return TRUE;
}
- else if (gst_structure_has_name (s, "farsight-local-candidates-prepared"))
+ else if (gst_structure_has_name (s, "farstream-local-candidates-prepared"))
{
cb_fs_local_candidates_prepared (stream);
}
- else if (gst_structure_has_name (s, "farsight-component-state-changed"))
+ else if (gst_structure_has_name (s, "farstream-component-state-changed"))
{
guint component;
FsStreamState fsstate;
diff --git a/telepathy-farstream/content-priv.h b/telepathy-farstream/content-priv.h
index 91acdea..bee82e3 100644
--- a/telepathy-farstream/content-priv.h
+++ b/telepathy-farstream/content-priv.h
@@ -4,7 +4,7 @@
#include <glib-object.h>
-#include <gst/farsight/fs-conference-iface.h>
+#include <farstream/fs-conference.h>
G_BEGIN_DECLS
diff --git a/telepathy-farstream/content.c b/telepathy-farstream/content.c
index a3dbe6b..7f23596 100644
--- a/telepathy-farstream/content.c
+++ b/telepathy-farstream/content.c
@@ -2,7 +2,7 @@
#include "content.h"
#include "content-priv.h"
-#include <gst/farsight/fs-conference-iface.h>
+#include <farstream/fs-conference.h>
#include "channel.h"
#include "tf-signals-marshal.h"
@@ -74,22 +74,22 @@ tf_content_class_init (TfContentClass *klass)
g_object_class_install_property (object_class, PROP_TF_CHANNEL,
g_param_spec_object ("tf-channel",
"Parent TfChannel object ",
- "The Telepathy-Farsight Channel for this object",
+ "The Telepathy-Farstream Channel for this object",
TF_TYPE_CHANNEL,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
g_object_class_install_property (object_class, PROP_FS_CONFERENCE,
g_param_spec_object ("fs-conference",
- "Farsight2 FsConference used by the Content ",
- "The Farsight2 conference for this content "
+ "Farstream FsConference used by the Content ",
+ "The Farstream conference for this content "
"(could be the same as other contents)",
FS_TYPE_CONFERENCE,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
g_object_class_install_property (object_class, PROP_FS_SESSION,
g_param_spec_object ("fs-session",
- "Farsight2 FsSession ",
- "The Farsight2 session for this content",
+ "Farstream FsSession ",
+ "The Farstream session for this content",
FS_TYPE_SESSION,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
diff --git a/telepathy-farstream/content.h b/telepathy-farstream/content.h
index d5bf409..e071679 100644
--- a/telepathy-farstream/content.h
+++ b/telepathy-farstream/content.h
@@ -2,7 +2,7 @@
#define __TF_CONTENT_H__
#include <glib-object.h>
-#include <gst/farsight/fs-conference-iface.h>
+#include <farstream/fs-conference.h>
G_BEGIN_DECLS
diff --git a/telepathy-farstream/media-signalling-channel.c b/telepathy-farstream/media-signalling-channel.c
index a820973..bfd3696 100644
--- a/telepathy-farstream/media-signalling-channel.c
+++ b/telepathy-farstream/media-signalling-channel.c
@@ -24,7 +24,7 @@
*
* This class handles the
* org.freedesktop.Telepathy.Channel.Interface.MediaSignalling on a
- * channel using Farsight2.
+ * channel using Farstream.
*/
@@ -475,8 +475,8 @@ new_stream_cb (TfSession *session,
&local_codec_config);
g_object_get (session,
- "farsight-conference", &fs_conference,
- "farsight-participant", &fs_participant,
+ "farstream-conference", &fs_conference,
+ "farstream-participant", &fs_participant,
NULL);
stream = _tf_stream_new ((gpointer) self, fs_conference,
@@ -568,7 +568,7 @@ add_session (TfMediaSignallingChannel *self,
G_CALLBACK (session_invalidated_cb), self);
g_object_get (self->session,
- "farsight-conference", &conf,
+ "farstream-conference", &conf,
NULL);
g_signal_emit (self, signals[SESSION_CREATED], 0, conf);
diff --git a/telepathy-farstream/media-signalling-content.c b/telepathy-farstream/media-signalling-content.c
index 191250c..34c3ebc 100644
--- a/telepathy-farstream/media-signalling-content.c
+++ b/telepathy-farstream/media-signalling-content.c
@@ -25,14 +25,14 @@
*
* This class handles the
* org.freedesktop.Telepathy.Channel.Interface.MediaSignalling on a
- * channel using Farsight2.
+ * channel using Farstream.
*/
#include "media-signalling-content.h"
-#include <gst/farsight/fs-conference-iface.h>
-#include <gst/farsight/fs-utils.h>
+#include <farstream/fs-conference.h>
+#include <farstream/fs-utils.h>
#include <stdarg.h>
#include <string.h>
@@ -162,11 +162,11 @@ tf_media_signalling_content_get_property (GObject *object,
break;
case PROP_FS_CONFERENCE:
g_object_get_property (G_OBJECT (self->stream),
- "farsight-conference", value);
+ "farstream-conference", value);
break;
case PROP_FS_SESSION:
g_object_get_property (G_OBJECT (self->stream),
- "farsight-session", value);
+ "farstream-session", value);
break;
case PROP_SINK_PAD:
g_object_get_property (G_OBJECT (self->stream),
@@ -213,8 +213,8 @@ tf_media_signalling_content_new (
G_CALLBACK (restart_source), G_OBJECT (self), 0);
g_object_get (stream,
- "farsight-conference", &conf,
- "farsight-session", &session,
+ "farstream-conference", &conf,
+ "farstream-session", &session,
NULL);
codec_prefs = fs_utils_get_default_codec_preferences (conf);
@@ -235,7 +235,7 @@ src_pad_added (TfStream *stream, GstPad *pad, FsCodec *codec,
{
FsStream *fs_stream;
- g_object_get (stream, "farsight-stream", &fs_stream, NULL);
+ g_object_get (stream, "farstream-stream", &fs_stream, NULL);
_tf_content_emit_src_pad_added (TF_CONTENT (self), self->handle, fs_stream,
pad, codec);
g_object_unref (fs_stream);
@@ -316,8 +316,8 @@ tf_media_signalling_content_iterate_src_pads (TfContent *content,
g_return_val_if_fail (handle_count <= 1, NULL);
- g_object_get (self->stream, "farsight-stream", &fs_stream, NULL);
- iter = fs_stream_get_src_pads_iterator (fs_stream);
+ g_object_get (self->stream, "farstream-stream", &fs_stream, NULL);
+ iter = fs_stream_iterate_src_pads (fs_stream);
g_object_unref (fs_stream);
return iter;
diff --git a/telepathy-farstream/session.c b/telepathy-farstream/session.c
index c5f3494..42cb4db 100644
--- a/telepathy-farstream/session.c
+++ b/telepathy-farstream/session.c
@@ -22,7 +22,7 @@
#include <telepathy-glib/errors.h>
#include <telepathy-glib/interfaces.h>
-#include <gst/farsight/fs-conference.h>
+#include <farstream/fs-conference.h>
#include "session-priv.h"
#include "tf-signals-marshal.h"
@@ -44,8 +44,8 @@ enum
{
PROP_PROXY = 1,
PROP_SESSION_TYPE,
- PROP_FARSIGHT_CONFERENCE,
- PROP_FARSIGHT_PARTICIPANT,
+ PROP_FARSTREAM_CONFERENCE,
+ PROP_FARSTREAM_PARTICIPANT,
};
enum
@@ -79,10 +79,10 @@ _tf_session_get_property (GObject *object,
case PROP_SESSION_TYPE:
g_value_set_string (value, self->priv->session_type);
break;
- case PROP_FARSIGHT_CONFERENCE:
+ case PROP_FARSTREAM_CONFERENCE:
g_value_set_object (value, self->priv->fs_conference);
break;
- case PROP_FARSIGHT_PARTICIPANT:
+ case PROP_FARSTREAM_PARTICIPANT:
g_value_set_object (value, self->priv->fs_participant);
break;
case PROP_PROXY:
@@ -232,23 +232,23 @@ _tf_session_class_init (TfSessionClass *klass)
g_object_class_install_property (object_class, PROP_SESSION_TYPE,
g_param_spec_string ("conference-type",
- "Farsight conference type",
- "Name of the Farsight conference type this "
+ "Farstream conference type",
+ "Name of the Farstream conference type this "
"session will create (rtp, msn, etc).",
NULL,
G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
- g_object_class_install_property (object_class, PROP_FARSIGHT_CONFERENCE,
- g_param_spec_object ("farsight-conference",
- "Farsight conference",
- "The Farsight conference to add to the pipeline",
+ g_object_class_install_property (object_class, PROP_FARSTREAM_CONFERENCE,
+ g_param_spec_object ("farstream-conference",
+ "Farstream conference",
+ "The Farstream conference to add to the pipeline",
FS_TYPE_CONFERENCE,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
- g_object_class_install_property (object_class, PROP_FARSIGHT_PARTICIPANT,
- g_param_spec_object ("farsight-participant",
- "Farsight participant",
- "The Farsight participant for this session",
+ g_object_class_install_property (object_class, PROP_FARSTREAM_PARTICIPANT,
+ g_param_spec_object ("farstream-participant",
+ "Farstream participant",
+ "The Farstream participant for this session",
FS_TYPE_PARTICIPANT,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
@@ -418,7 +418,7 @@ _tf_session_bus_message (TfSession *session,
{
const GstStructure *s = gst_message_get_structure (message);
- if (gst_structure_has_name (s, "farsight-error"))
+ if (gst_structure_has_name (s, "farstream-error"))
{
GObject *object;
const GValue *value = NULL;
diff --git a/telepathy-farstream/stream.h b/telepathy-farstream/stream.h
index f50224f..ddd4b6b 100644
--- a/telepathy-farstream/stream.h
+++ b/telepathy-farstream/stream.h
@@ -5,7 +5,7 @@
#include <telepathy-glib/enums.h>
#include <telepathy-glib/media-interfaces.h>
-#include <gst/farsight/fs-conference-iface.h>
+#include <farstream/fs-conference.h>
G_BEGIN_DECLS
diff --git a/telepathy-farstream/telepathy-farstream-uninstalled.pc.in b/telepathy-farstream/telepathy-farstream-uninstalled.pc.in
index 7e6f073..37fc765 100644
--- a/telepathy-farstream/telepathy-farstream-uninstalled.pc.in
+++ b/telepathy-farstream/telepathy-farstream-uninstalled.pc.in
@@ -4,8 +4,8 @@ abs_top_srcdir=@abs_top_srcdir@
abs_top_builddir=@abs_top_builddir@
Name: Telepathy-Farstream
-Description: Library implementing the Telepathy Call API using Farsight2
+Description: Library implementing the Telepathy Call API using Farstream
Version: @VERSION@
-Requires.private: dbus-glib-1 >= 0.73, glib-2.0 >= 2.10, gobject-2.0 >= 2.10, farsight2-0.10 > 0.0.3
+Requires.private: dbus-glib-1 >= 0.73, glib-2.0 >= 2.10, gobject-2.0 >= 2.10, farstream-0.1
Libs: ${abs_top_builddir}/telepathy-farstream/libtelepathy-farstream.la
Cflags: -I${abs_top_srcdir} -I${abs_top_builddir}
diff --git a/telepathy-farstream/telepathy-farstream.pc.in b/telepathy-farstream/telepathy-farstream.pc.in
index 04b3580..de2d00f 100644
--- a/telepathy-farstream/telepathy-farstream.pc.in
+++ b/telepathy-farstream/telepathy-farstream.pc.in
@@ -4,8 +4,8 @@ libdir=@libdir@
includedir=@includedir@
Name: Telepathy-Farstream
-Description: Library implementing the Telepathy Call API using Farsight2
+Description: Library implementing the Telepathy Call API using Farstream
Version: @VERSION@
-Requires.private: dbus-glib-1 >= 0.73, glib-2.0 >= 2.10, gobject-2.0 >= 2.10, farsight2-0.10 > 0.0.3, telepathy-glib >= 0.7.23, gstreamer-0.10
+Requires.private: dbus-glib-1 >= 0.73, glib-2.0 >= 2.10, gobject-2.0 >= 2.10, farstream-0.10, telepathy-glib >= 0.7.23, gstreamer-0.10
Libs: -L${libdir} -ltelepathy-farstream
Cflags: -I${includedir}/telepathy-1.0
diff --git a/telepathy-farstream/utils.h b/telepathy-farstream/utils.h
index a3a922d..934924c 100644
--- a/telepathy-farstream/utils.h
+++ b/telepathy-farstream/utils.h
@@ -5,9 +5,9 @@
* tp_media_type_to_fs:
* @type: A Telepathy Media Stream Type
*
- * Converts a Telepathy Media Stream Type to the Farsight2 equivalent
+ * Converts a Telepathy Media Stream Type to the Farstream equivalent
*
- * Return: A Farsight2 Stream Type
+ * Return: A Farstream Stream Type
*/
static inline FsMediaType
diff --git a/telepathy-farstream/channel.c b/telepathy-farstream/channel.c
index 8d393c6..d2f77b0 100644
--- a/telepathy-farstream/channel.c
+++ b/telepathy-farstream/channel.c
@@ -25,7 +25,7 @@
*
* This class handles the
* org.freedesktop.Telepathy.Channel.Interface.MediaSignalling on a
* channel using Farsight2 or the media part of the
* org.freedesktop.Telepathy.Channel.Type.Call that has HardwareStreaming=FALSE
*/
@@ -38,7 +38,7 @@
#include <telepathy-glib/interfaces.h>
#include <telepathy-glib/util.h>
-#include <gst/farsight/fs-conference-iface.h>
+#include <farstream/fs-conference.h>
#include "extensions/extensions.h"
@@ -462,8 +462,8 @@ tf_channel_class_init (TfChannelClass *klass)
g_object_class_install_property (object_class, PROP_FS_CONFERENCES,
g_param_spec_boxed ("fs-conferences",
- "Farsight2 FsConferences objects",
- "GPtrArray of Farsight2 FsConferences for this channel",
+ "Farstream FsConferences objects",
+ "GPtrArray of Farstream FsConferences for this channel",
G_TYPE_PTR_ARRAY,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
@@ -25,7 +25,7 @@
* This class handles the
* org.freedesktop.Telepathy.Channel.Interface.MediaSignalling on a
- * channel using Farsight2 or the media part of the
+ * channel using Farstream or the media part of the
* org.freedesktop.Telepathy.Channel.Type.Call that has HardwareStreaming=FALSE
*/
diff --git a/telepathy-farstream/stream.c b/telepathy-farstream/stream.c
index 241cadd..89762c9 100644
--- a/telepathy-farstream/stream.c
+++ b/telepathy-farstream/stream.c
@@ -22,7 +22,7 @@
* SECTION:stream
* @short_description: Handles a media Stream
*
* These objects handle media streams and wrap the appropriate Farsight 2
* objects. It is used to interact on a stream level with the other parts
* of the media pipeline and the proper UI.
*/
@@ -41,9 +41,9 @@
#include <telepathy-glib/interfaces.h>
#include <telepathy-glib/util.h>
-#include <gst/farsight/fs-conference.h>
-#include <gst/farsight/fs-rtp.h>
-#include <gst/farsight/fs-utils.h>
+#include <farstream/fs-conference.h>
+#include <farstream/fs-rtp.h>
+#include <farstream/fs-utils.h>
#include "stream.h"
#include "stream-priv.h"
@@ -141,10 +141,10 @@ static guint signals[SIGNAL_COUNT] = {0};
enum
{
PROP_CHANNEL = 1,
- PROP_FARSIGHT_CONFERENCE,
- PROP_FARSIGHT_SESSION,
- PROP_FARSIGHT_STREAM,
- PROP_FARSIGHT_PARTICIPANT,
+ PROP_FARSTREAM_CONFERENCE,
+ PROP_FARSTREAM_SESSION,
+ PROP_FARSTREAM_STREAM,
+ PROP_FARSTREAM_PARTICIPANT,
PROP_PROXY,
PROP_STREAM_ID,
PROP_MEDIA_TYPE,
@@ -270,16 +270,16 @@ tf_stream_get_property (GObject *object,
case PROP_CHANNEL:
g_value_set_object (value, self->priv->channel);
break;
- case PROP_FARSIGHT_CONFERENCE:
+ case PROP_FARSTREAM_CONFERENCE:
g_value_set_object (value, self->priv->fs_conference);
break;
- case PROP_FARSIGHT_PARTICIPANT:
+ case PROP_FARSTREAM_PARTICIPANT:
g_value_set_object (value, self->priv->fs_participant);
break;
- case PROP_FARSIGHT_SESSION:
+ case PROP_FARSTREAM_SESSION:
g_value_set_object (value, self->priv->fs_session);
break;
- case PROP_FARSIGHT_STREAM:
+ case PROP_FARSTREAM_STREAM:
g_value_set_object (value, self->priv->fs_stream);
break;
case PROP_PROXY:
@@ -334,11 +334,11 @@ tf_stream_set_property (GObject *object,
self->priv->channel =
TF_CHANNEL (g_value_get_object (value));
break;
- case PROP_FARSIGHT_CONFERENCE:
+ case PROP_FARSTREAM_CONFERENCE:
self->priv->fs_conference =
FS_CONFERENCE (g_value_dup_object (value));
break;
- case PROP_FARSIGHT_PARTICIPANT:
+ case PROP_FARSTREAM_PARTICIPANT:
self->priv->fs_participant =
FS_PARTICIPANT (g_value_dup_object (value));
break;
@@ -509,33 +509,33 @@ tf_stream_class_init (TfStreamClass *klass)
TF_TYPE_CHANNEL,
G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
- g_object_class_install_property (object_class, PROP_FARSIGHT_CONFERENCE,
- g_param_spec_object ("farsight-conference",
- "Farsight conference",
- "The Farsight conference this stream will "
+ g_object_class_install_property (object_class, PROP_FARSTREAM_CONFERENCE,
+ g_param_spec_object ("farstream-conference",
+ "Farstream conference",
+ "The Farstream conference this stream will "
"create streams within.",
FS_TYPE_CONFERENCE,
G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
- g_object_class_install_property (object_class, PROP_FARSIGHT_PARTICIPANT,
- g_param_spec_object ("farsight-participant",
- "Farsight participant",
- "The Farsight participant this stream will "
+ g_object_class_install_property (object_class, PROP_FARSTREAM_PARTICIPANT,
+ g_param_spec_object ("farstream-participant",
+ "Farstream participant",
+ "The Farstream participant this stream will "
"create streams for.",
FS_TYPE_PARTICIPANT,
G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
- g_object_class_install_property (object_class, PROP_FARSIGHT_SESSION,
- g_param_spec_object ("farsight-session",
- "Farsight session",
- "The Farsight session",
+ g_object_class_install_property (object_class, PROP_FARSTREAM_SESSION,
+ g_param_spec_object ("farstream-session",
+ "Farstream session",
+ "The Farstream session",
FS_TYPE_SESSION,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
- g_object_class_install_property (object_class, PROP_FARSIGHT_STREAM,
- g_param_spec_object ("farsight-stream",
- "Farsight stream",
- "The Farsight stream",
+ g_object_class_install_property (object_class, PROP_FARSTREAM_STREAM,
+ g_param_spec_object ("farstream-stream",
+ "Farstream stream",
+ "The Farstream stream",
FS_TYPE_STREAM,
G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
@@ -1306,7 +1306,7 @@ tp_transports_to_fs (const gchar* foundation, const GPtrArray *transports)
type = FS_CANDIDATE_TYPE_RELAY;
break;
default:
- g_critical ("%s: FarsightTransportInfo.proto has an invalid value",
+ g_critical ("%s: FarstreamTransportInfo.proto has an invalid value",
G_STRFUNC);
type = FS_CANDIDATE_TYPE_HOST;
}
@@ -1320,7 +1320,7 @@ tp_transports_to_fs (const gchar* foundation, const GPtrArray *transports)
proto = FS_NETWORK_PROTOCOL_TCP;
break;
default:
- g_critical ("%s: FarsightTransportInfo.proto has an invalid value",
+ g_critical ("%s: FarstreamTransportInfo.proto has an invalid value",
G_STRFUNC);
proto = FS_NETWORK_PROTOCOL_UDP;
}
@@ -1358,7 +1358,7 @@ fs_network_proto_to_tp (FsNetworkProtocol proto, gboolean *valid)
case FS_NETWORK_PROTOCOL_TCP:
return TP_MEDIA_STREAM_BASE_PROTO_TCP;
default:
- g_critical ("%s: FarsightTransportInfo.proto has an invalid value",
+ g_critical ("%s: FarstreamTransportInfo.proto has an invalid value",
G_STRFUNC);
if (valid != NULL)
*valid = FALSE;
@@ -1381,7 +1381,7 @@ fs_candidate_type_to_tp (FsCandidateType type, gboolean *valid)
case FS_CANDIDATE_TYPE_RELAY:
return TP_MEDIA_STREAM_TRANSPORT_TYPE_RELAY;
default:
- g_critical ("%s: FarsightTransportInfo.proto has an invalid value",
+ g_critical ("%s: FarstreamTransportInfo.proto has an invalid value",
G_STRFUNC);
if (valid != NULL)
*valid = FALSE;
@@ -1421,7 +1421,7 @@ fs_candidate_to_tp_array (const FsCandidate *candidate)
}
/*
* Small helper function to help converting a list of FarsightCodecs
* to a Telepathy codec list.
*/
static GPtrArray *
@@ -1449,7 +1449,7 @@ fs_codecs_to_tp (TfStream *stream,
type = TP_MEDIA_STREAM_TYPE_VIDEO;
break;
default:
- g_critical ("%s: FarsightCodec [%d, %s]'s media_type has an invalid value",
+ g_critical ("%s: FarstreamCodec [%d, %s]'s media_type has an invalid value",
G_STRFUNC, fsc->id, fsc->encoding_name);
return NULL;
}
@@ -2463,7 +2463,7 @@ _tf_stream_bus_message (TfStream *stream,
if (!stream->priv->fs_stream || !stream->priv->fs_session)
return FALSE;
- if (gst_structure_has_name (s, "farsight-error"))
+ if (gst_structure_has_name (s, "farstream-error"))
{
GObject *object;
const GValue *value = NULL;
@@ -2493,7 +2493,7 @@ _tf_stream_bus_message (TfStream *stream,
return TRUE;
}
}
- else if (gst_structure_has_name (s, "farsight-new-local-candidate"))
+ else if (gst_structure_has_name (s, "farstream-new-local-candidate"))
{
FsStream *fsstream;
FsCandidate *candidate;
@@ -2511,7 +2511,7 @@ _tf_stream_bus_message (TfStream *stream,
cb_fs_new_local_candidate (stream, candidate);
return TRUE;
}
- else if (gst_structure_has_name (s, "farsight-local-candidates-prepared"))
+ else if (gst_structure_has_name (s, "farstream-local-candidates-prepared"))
{
FsStream *fsstream;
const GValue *value;
@@ -2526,7 +2526,7 @@ _tf_stream_bus_message (TfStream *stream,
return TRUE;
}
- else if (gst_structure_has_name (s, "farsight-new-active-candidate-pair"))
+ else if (gst_structure_has_name (s, "farstream-new-active-candidate-pair"))
{
FsStream *fsstream;
FsCandidate *local_candidate;
@@ -2548,7 +2548,7 @@ _tf_stream_bus_message (TfStream *stream,
cb_fs_new_active_candidate_pair (stream, local_candidate, remote_candidate);
return TRUE;
}
- else if (gst_structure_has_name (s, "farsight-current-recv-codecs-changed"))
+ else if (gst_structure_has_name (s, "farstream-current-recv-codecs-changed"))
{
FsStream *fsstream;
GList *codecs;
@@ -2566,7 +2566,7 @@ _tf_stream_bus_message (TfStream *stream,
cb_fs_recv_codecs_changed (stream, codecs);
return TRUE;
}
- else if (gst_structure_has_name (s, "farsight-codecs-changed"))
+ else if (gst_structure_has_name (s, "farstream-codecs-changed"))
{
FsSession *fssession;
const GValue *value;
@@ -2583,7 +2583,7 @@ _tf_stream_bus_message (TfStream *stream,
return TRUE;
}
- else if (gst_structure_has_name (s, "farsight-send-codec-changed"))
+ else if (gst_structure_has_name (s, "farstream-send-codec-changed"))
{
FsSession *fssession;
const GValue *value;
@@ -2622,7 +2622,7 @@ _tf_stream_bus_message (TfStream *stream,
fs_codec_list_destroy (secondary_codecs);
return TRUE;
}
- else if (gst_structure_has_name (s, "farsight-component-state-changed"))
+ else if (gst_structure_has_name (s, "farstream-component-state-changed"))
{
FsStream *fsstream;
const GValue *value;
@@ -2643,7 +2643,7 @@ _tf_stream_bus_message (TfStream *stream,
cb_fs_component_state_changed (stream, component, fsstate);
return TRUE;
}
- else if (gst_structure_has_name (s, "farsight-renegotiate"))
+ else if (gst_structure_has_name (s, "farstream-renegotiate"))
{
FsSession *fssession;
const GValue *value;
@@ -2726,8 +2726,8 @@ _tf_stream_new (gpointer channel,
self = g_object_new (TF_TYPE_STREAM,
"channel", channel,
- "farsight-conference", conference,
- "farsight-participant", participant,
+ "farstream-conference", conference,
+ "farstream-participant", participant,
"proxy", proxy,
"stream-id", stream_id,
"media-type", media_type,
@@ -22,7 +22,7 @@
* @short_description: Handles a media Stream
*
- * These objects handle media streams and wrap the appropriate Farsight 2
+ * These objects handle media streams and wrap the appropriate Farstream
* objects. It is used to interact on a stream level with the other parts
* of the media pipeline and the proper UI.
@@ -1421,7 +1421,7 @@ fs_candidate_to_tp_array (const FsCandidate *candidate)
}
/*
- * Small helper function to help converting a list of FarsightCodecs
+ * Small helper function to help converting a list of FarstreamCodecs
* to a Telepathy codec list.
*/